/*
 * System Interface Library for games
 * Copyright (c) 2007-2017 Andrew Church <achurch@achurch.org>
 * Released under the GNU GPL version 3 or later; NO WARRANTY is provided.
 * See the file COPYING.txt for details.
 *
 * include/SIL/configs/windows.h: Configuration header for Windows.
 */

#ifndef SIL_CONFIGS_WINDOWS_H
#define SIL_CONFIGS_WINDOWS_H

/*************************************************************************/
/*************************************************************************/

#define SIL_PLATFORM_WINDOWS
#define SIL_SYSTEM_COMMON_HEADER  "sysdep/windows/common.h"

/* Windows only runs on little-endian platforms. */
#define IS_LITTLE_ENDIAN

#ifdef _MSC_VER

# define HAVE__STRICMP
# define STRNICMP_SIZE_T  size_t

/* Disable various unneeded warnings. */
# pragma warning(disable:4018)  // Signed/unsigned comparison
# pragma warning(disable:4244)  // Loss of numeric precision (integer size)
# pragma warning(disable:4258)  // Not using for-scope extension (why warn...?)
# pragma warning(disable:4267)  // Loss of numeric precision (size_t -> int)
# pragma warning(disable:4305)  // Loss of numeric precision (generic)
# pragma warning(disable:4800)  // Conversion of non-bool to bool
# pragma warning(disable:4805)  // Comparison of non-bool and bool

# if !defined(__cplusplus)
#  define inline __inline
# endif

# undef _DEBUG  // Use in MS headers conflicts with some of our code.

#else  // !_MSC_VER

# if defined(__i386__)
#  define SIL_ARCH_X86
#  define SIL_ARCH_X86_32
# elif defined(__x86_64__)
#  define SIL_ARCH_X86
#  define SIL_ARCH_X86_64
# elif defined(__arm__)
#  define SIL_ARCH_ARM
#  define SIL_ARCH_ARM_V7A
# else
#  warning Unknown CPU architecture!
# endif

/* MinGW's libc has strcasecmp() but not in <strings.h>, so use our own
 * instead. */
//# define HAVE_STRCASECMP 1  // Define to 1 to avoid SDL_config.h collision.
//# define STRNICMP_SIZE_T  size_t

#endif

/* We use a custom DLOG() implementation to avoid stdio collisions
 * between MinGW's libc and MSVCRT. */
#define SIL_DLOG_CUSTOM

/* Windows priorities range from +2 to -2. */
#define SIL_OPENAL_THREAD_PRIORITY  1

/* The default OpenAL implementation for Windows is horribly broken with
 * more than a few voices, so handle mixing ourselves. */
#define SIL_OPENAL_USE_INTERNAL_MIXER
#define SIL_OPENAL_INTERNAL_MIXER_RATE  48000

/* Enable dynamic loading of the OpenGL library. */
#define SIL_SDL_DYNAMIC_OPENGL

/*************************************************************************/
/*************************************************************************/

#endif  // SIL_CONFIGS_WINDOWS_H

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
