/*
 * System Interface Library for games
 * Copyright (c) 2007-2017 Andrew Church <achurch@achurch.org>
 * Released under the GNU GPL version 3 or later; NO WARRANTY is provided.
 * See the file COPYING.txt for details.
 *
 * src/sysdep/macosx/internal.h: Common header for declarations internal to
 * OSX-specific code.
 */

/*
 * The system headers CoreFoundation/CFBase.h and CoreServices/CoreServices.h
 * make their own use of the DEBUG symbol (the latter through an internal
 * Debugging.h header), so we include them here with our definition of DEBUG
 * hidden.  All sources which include OSX-specific headers should include
 * this header first to ensure that these headers are properly processed.
 */

#ifndef SIL_SRC_SYSDEP_MACOSX_INTERNAL_H
#define SIL_SRC_SYSDEP_MACOSX_INTERNAL_H

/*************************************************************************/
/*************************************************************************/

#ifdef DEBUG
# define SIL_DEBUG
# undef DEBUG
#endif

#include <CoreFoundation/CFBase.h>
#include <CoreServices/CoreServices.h>

#ifdef SIL_DEBUG
# undef SIL_DEBUG
# define DEBUG
#endif

/*-----------------------------------------------------------------------*/

/* Internal utility functions: */

/**
 * ios_get_application_name:  Return the name of the current application,
 * or "The application" (capitalized) if the application name cannot be
 * determined.
 *
 * [Return value]
 *     Application name.
 */
extern const char *macosx_get_application_name(void);

/*************************************************************************/
/*************************************************************************/

#endif  // SIL_SRC_SYSDEP_MACOSX_INTERNAL_H

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
