/*
 * System Interface Library for games
 * Copyright (c) 2007-2017 Andrew Church <achurch@achurch.org>
 * Released under the GNU GPL version 3 or later; NO WARRANTY is provided.
 * See the file COPYING.txt for details.
 *
 * src/sysdep/posix/thread.h: POSIX-specific thread management function
 * declarations.
 */

#ifndef SIL_SRC_SYSDEP_POSIX_THREAD_H
#define SIL_SRC_SYSDEP_POSIX_THREAD_H

/*************************************************************************/
/*************************************************************************/

/**
 * posix_thread_create_detached:  Create and start a thread executing the
 * given function.  The function should accept a single pointer parameter
 * and return nothing.
 *
 * Unlike sys_thread_create(), the thread will be destroyed as soon as the
 * function returns; there is no way for the caller to determine when the
 * thread has exited.
 *
 * [Parameters]
 *     function: Function to execute.
 *     param: Arbitrary parameter to pass to the function.
 * [Return value]
 *     True on success, false on error.
 */
extern int posix_thread_create_detached(void (*function)(void *), void *param);

/**
 * posix_thread_exit:  Terminate the current thread.  Call this function
 * instead of pthread_exit() to ensure that system-specific cleanup is
 * performed before the thread is deleted.
 *
 * This function does not return.
 *
 * [Parameters]
 *     retval: Thread result value.
 */
extern NORETURN void posix_thread_exit(int retval);

/*************************************************************************/
/*************************************************************************/

#endif  // SIL_SRC_SYSDEP_POSIX_THREAD_H

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
