/*
 * System Interface Library for games
 * Copyright (c) 2007-2017 Andrew Church <achurch@achurch.org>
 * Released under the GNU GPL version 3 or later; NO WARRANTY is provided.
 * See the file COPYING.txt for details.
 *
 * src/sysdep/posix/userdata.h: Test control header for POSIX user data
 * access routines.
 */

#ifndef SIL_SRC_SYSDEP_POSIX_USERDATA_H
#define SIL_SRC_SYSDEP_POSIX_USERDATA_H

/*************************************************************************/
/************************ Test control interface *************************/
/*************************************************************************/

#ifdef INCLUDE_TESTS

/**
 * TEST_posix_userdata_path:  If not NULL, this path will be used in
 * place of the path returned by sys_userdata_get_data_path() when
 * generating pathnames for user data files.
 */
extern const char *TEST_posix_userdata_path;

/**
 * TEST_posix_userdata_unregister_stats:  Unregister any statistics
 * registered with a REGISTER_STATS operation.
 */
extern void TEST_posix_userdata_unregister_stats(void);

#endif  // INCLUDE_TESTS

/*************************************************************************/
/*********************** Library-internal routines ***********************/
/*************************************************************************/

/**
 * posix_userdata_init:  Initialize the POSIX-specific userdata
 * functionality.  This must be called during program startup.
 *
 * [Return value]
 *     True on success, false on error.
 */
extern int posix_userdata_init(void);

/*************************************************************************/
/*************************************************************************/

#endif  // SIL_SRC_SYSDEP_POSIX_USERDATA_H

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
